@@ -14,12 +14,18 @@ use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
  */
 class AwsRetryStrategy extends GenericRetryStrategy
 {
+    // Override Symfony default options for a better integration of AWS servers.
     public const DEFAULT_RETRY_STATUS_CODES = [0, 423, 425, 429, 500, 502, 503, 504, 507, 510];
 
+    /**
+     * @var AwsErrorFactoryInterface
+     */
     private $awsErrorFactory;
 
-    // Override Symfony default options for a better integration of AWS servers.
-    public function __construct(array $statusCodes = self::DEFAULT_RETRY_STATUS_CODES, int $delayMs = 1000, float $multiplier = 2.0, int $maxDelayMs = 0, float $jitter = 0.1, AwsErrorFactoryInterface $awsErrorFactory = null)
+    /**
+     * @param array<int, int|string[]> $statusCodes
+     */
+    public function __construct(array $statusCodes = self::DEFAULT_RETRY_STATUS_CODES, int $delayMs = 1000, float $multiplier = 2.0, int $maxDelayMs = 0, float $jitter = 0.1, ?AwsErrorFactoryInterface $awsErrorFactory = null)
     {
         parent::__construct($statusCodes, $delayMs, $multiplier, $maxDelayMs, $jitter);
         $this->awsErrorFactory = $awsErrorFactory ?? new ChainAwsErrorFactory();
