@@ -5,20 +5,33 @@ namespace AsyncAws\Core\Signer;
 use AsyncAws\Core\Request;
 
 /**
- * @internal
- *
  * @author Jérémy Derussé <jeremy@derusse.com>
  */
-class SigningContext
+final class SigningContext
 {
+    /**
+     * @var Request
+     */
     private $request;
 
+    /**
+     * @var \DateTimeImmutable
+     */
     private $now;
 
+    /**
+     * @var string
+     */
     private $credentialString;
 
+    /**
+     * @var string
+     */
     private $signingKey;
 
+    /**
+     * @var string
+     */
     private $signature = '';
 
     public function __construct(
